.. FACILE-RS documentation master file, created by
   sphinx-quickstart on Sat May  4 11:13:06 2024.
   You can adapt this file completely to your liking,
   but it should at least contain the root `toctree`
   directive.


Welcome to the documentation of FACILE-RS!
==========================================
.. doesn't seem to have an effect
.. currentmodule:: facile_rs

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   apidocs/index

.. Indices
.. =======

* :ref:`Index <genindex>`

.. * :ref:`Module Index <modindex>`

.. * :ref:`search`
